
/**************************************************************************
**  (c) Copyright 2002, Andromeda Technology & Automation
***************************************************************************
** MODULE INFORMATION *
***********************
**      FILE NAME      : database.cpp
**      SYSTEM NAME    : Gnucomo - Gnu Computer Monitoring
**      VERSION NUMBER : $Revision: 1.1 $
**
**  DESCRIPTION      :  Implementation of the gnucomo database classes
**
**  EXPORTED OBJECTS : 
**  LOCAL    OBJECTS : 
**  MODULES  USED    :
***************************************************************************
**  ADMINISTRATIVE INFORMATION *
********************************
**      ORIGINAL AUTHOR : Arjen Baart - arjen@andromeda.nl
**      CREATION DATE   : Sep 10, 2002
**      LAST UPDATE     : Sep 26, 2002
**      MODIFICATIONS   : 
**************************************************************************/

/*****************************
   $Log: database.cpp,v $
   Revision 1.1  2002/10/05 10:25:49  arjen
   Creation of gcm_input and a first approach to a web interface

*****************************/

static const char *RCSID = "$Id: database.cpp,v 1.1 2002/10/05 10:25:49 arjen Exp $";

#include "database.h"

extern bool verbose;   /*  Defined in the main application */

/*=========================================================================
**  NAME           : gnucomo_database
**  SYNOPSIS       : gnucomo_database(gnucomo_config &c);
**  PARAMETERS     : 
**  RETURN VALUE   : Database constructor. Establishes a connection with
**                   the database server.
**
**  DESCRIPTION    : 
**
**  VARS USED      :
**  VARS CHANGED   :
**  FUNCTIONS USED :
**  SEE ALSO       :
**  LAST MODIFIED  : Sep 26, 2002
**=========================================================================
*/

gnucomo_database::gnucomo_database(gnucomo_config *c)
{
   cfg = c;

   if (verbose)
   {
      cout <<  "Database connection string = " << cfg->Database() << "\n";
   }

   db = new PgDatabase(cfg->Database());

   if (db->ConnectionBad())
   {
      cerr << "Can not connect to database: " << db->ErrorMessage();
   }
}

/*=========================================================================
**  NAME           : find_host
**  SYNOPSIS       : String gnucomo_database::find_host(String hostname);
**  PARAMETERS     : 
**  RETURN VALUE   : Find a hostname in the 'object' table of the gnucomo database
**                   and return its object id.
**                   Return an empty string as objectid if the hostname is
**                   not found.
**
**  DESCRIPTION    : 
**
**  VARS USED      :
**  VARS CHANGED   :
**  FUNCTIONS USED :
**  SEE ALSO       :
**  LAST MODIFIED  : Sep 16, 2002
**=========================================================================
*/

String gnucomo_database::find_host(const String hostname)
{
   String objectid("");
   String check_host("select objectid from object where ");

   check_host += "objectname = '";
   check_host += hostname;
   check_host += "'";

   if (Query(check_host) > 0)
   {
      objectid = String(db->GetValue(0, "objectid"));
   }

   return objectid;
}
